==> igniteui-angular-core-17.3.0.tgz: package/esm2015/lib/WebDateTimeFilteringOperandDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebBaseDateTimeFilteringOperandDescriptionMetadata } from "./WebBaseDateTimeFilteringOperandDescriptionMetadata";
import { WebDateTimeFilteringOperandDescription } from "./WebDateTimeFilteringOperandDescription";
/**
 * @hidden
 */
export let WebDateTimeFilteringOperandDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebDateTimeFilteringOperandDescriptionMetadata extends Base {
        static b(a) {
            if (WebDateTimeFilteringOperandDescriptionMetadata.a == null) {
                WebDateTimeFilteringOperandDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebDateTimeFilteringOperandDescriptionMetadata.c(WebDateTimeFilteringOperandDescriptionMetadata.a);
            }
            if (a.k(WebDateTimeFilteringOperandDescriptionMetadata.a)) {
                return;
            }
            a.ab(WebDateTimeFilteringOperandDescriptionMetadata.a);
        }
        static c(a) {
            WebBaseDateTimeFilteringOperandDescriptionMetadata.c(a);
            a.item("__qualifiedNameTS", "String:DateTimeFilteringOperand");
            a.item("__packageNameWC", "String:grids");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importOverrideWebComponents", "String:igniteui-webcomponents-grids/grids/combined");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents-grids/grids");
            a.item("__skipSuffix", "Boolean");
        }
        static d(a) {
            WebDateTimeFilteringOperandDescriptionMetadata.b(a);
            a.ad("WebDateTimeFilteringOperand", () => new WebDateTimeFilteringOperandDescription());
            a.ac("WebDateTimeFilteringOperand", WebDateTimeFilteringOperandDescriptionMetadata.a);
        }
    }
    WebDateTimeFilteringOperandDescriptionMetadata.$t = markType(WebDateTimeFilteringOperandDescriptionMetadata, 'WebDateTimeFilteringOperandDescriptionMetadata');
    WebDateTimeFilteringOperandDescriptionMetadata.a = null;
    return WebDateTimeFilteringOperandDescriptionMetadata;
})();

==> igniteui-angular-core-20.0.0.tgz: package/esm2015/lib/WebDateTimeFilteringOperandDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebBaseDateTimeFilteringOperandDescriptionMetadata } from "./WebBaseDateTimeFilteringOperandDescriptionMetadata";
import { WebDateTimeFilteringOperandDescription } from "./WebDateTimeFilteringOperandDescription";
/**
 * @hidden
 */
export let WebDateTimeFilteringOperandDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebDateTimeFilteringOperandDescriptionMetadata extends Base {
        static b(a) {
            if (WebDateTimeFilteringOperandDescriptionMetadata.a == null) {
                WebDateTimeFilteringOperandDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebDateTimeFilteringOperandDescriptionMetadata.c(WebDateTimeFilteringOperandDescriptionMetadata.a);
            }
            if (a.k(WebDateTimeFilteringOperandDescriptionMetadata.a)) {
                return;
            }
            a.ac(WebDateTimeFilteringOperandDescriptionMetadata.a);
        }
        static c(a) {
            WebBaseDateTimeFilteringOperandDescriptionMetadata.c(a);
            a.item("__qualifiedNameTS", "String:DateTimeFilteringOperand");
            a.item("__packageNameWC", "String:grids");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importOverrideWebComponents", "String:igniteui-webcomponents-grids/grids/combined");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents-grids/grids");
            a.item("__skipSuffix", "Boolean");
        }
        static d(a) {
            WebDateTimeFilteringOperandDescriptionMetadata.b(a);
            a.ae("WebDateTimeFilteringOperand", () => new WebDateTimeFilteringOperandDescription());
            a.ad("WebDateTimeFilteringOperand", WebDateTimeFilteringOperandDescriptionMetadata.a);
        }
    }
    WebDateTimeFilteringOperandDescriptionMetadata.$t = markType(WebDateTimeFilteringOperandDescriptionMetadata, 'WebDateTimeFilteringOperandDescriptionMetadata');
    WebDateTimeFilteringOperandDescriptionMetadata.a = null;
    return WebDateTimeFilteringOperandDescriptionMetadata;
})();
